@@ -56,7 +56,9 @@ public:
     CGG1_STOCK_2,
     CGDN1,
     CGD1,
-    CGDK2,
+    CGDK2_STOCK,
+    CGDK2_PVVX,
+    CGDK2_ATC1441,
     CGH1,
     JQJCY01YM,
     IBSTHBP01B,
@@ -64,8 +66,6 @@ public:
     IBT_2XS,
     IBT4XS,
     IBT6XS_SOLIS,
-    APPLE_CONT,
-    APPLE_CONTAT,
     MIBAND,
     XMTZC04HM,
     XMTZC05HM,
@@ -118,9 +118,11 @@ public:
     TAGIT,
     TILE,
     TILEN,
-    IBEACON,
-    SERVICE_DATA,
     JHT_F525,
+    IBEACON,
+    APPLE_CONT,
+    APPLE_CONTAT,
+    SERVICE_DATA,
     BLE_ID_MAX
   };
 
